@@ -1,7 +1,7 @@
 # coding: utf-8
 import os
 import unittest
-from StringIO import StringIO
+import io
 
 from lxml import etree
 
@@ -15,13 +15,13 @@ SAMPLES_PATH = os.path.join(
 
 class SetupTests(unittest.TestCase):
     def test_message_is_splitted(self):
-        fp = etree.parse(StringIO(b'<a><b>bar</b></a>'))
+        fp = etree.parse(io.BytesIO(b'<a><b>bar</b></a>'))
         self.assertEqual(checks.setup(fp), (fp, []))
 
 
 class TeardownTests(unittest.TestCase):
     def test_returns_errorlist(self):
-        fp = etree.parse(StringIO(b'<a><b>bar</b></a>'))
+        fp = etree.parse(io.BytesIO(b'<a><b>bar</b></a>'))
         err_list = ['some error']
         message = (fp, err_list)
         self.assertEqual(checks.teardown(message), err_list)
@@ -245,7 +245,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.funding_group((et, []))
 
-        self.assertEquals(len(err_list), 0)
+        self.assertEqual(len(err_list), 0)
 
     def test_proposition_1_case_2(self):
         """
@@ -253,7 +253,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         HasFundingGroup is False
         (HasExplicitContract <=> HasFundingGroup) is False
         """
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <article>
           <front>
             <article-meta></article-meta>
@@ -271,7 +271,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.funding_group((et, []))
 
-        self.assertEquals(len(err_list), 1)
+        self.assertEqual(len(err_list), 1)
         self.assertTrue("'funding-group'" in err_list[0].message)
 
     def test_proposition_1_case_3(self):
@@ -280,7 +280,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         HasFundingGroup is True
         (HasExplicitContract <=> HasFundingGroup) is False
         """
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <article>
           <front>
             <article-meta>
@@ -306,7 +306,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.funding_group((et, []))
 
-        self.assertEquals(len(err_list), 1)
+        self.assertEqual(len(err_list), 1)
         self.assertTrue("'funding-group'" in err_list[0].message)
 
     def test_proposition_1_case_4(self):
@@ -315,7 +315,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         HasFundingGroup is False
         (HasExplicitContract <=> HasFundingGroup) is True
         """
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <article>
           <front>
             <article-meta></article-meta>
@@ -333,7 +333,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.funding_group((et, []))
 
-        self.assertEquals(len(err_list), 0)
+        self.assertEqual(len(err_list), 0)
 
     def test_proposition_3_case_1(self):
         """
@@ -341,7 +341,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         ∀ContractNo<ack> [ Registered(FundingGroup, ContractNo) ] ^
         ∀ContractNo<funding-group> [ Registered(Ack, ContractNo) v Registered(Fn, ContractNo) ]
         """
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <article>
           <front>
             <article-meta>
@@ -370,7 +370,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.funding_group((et, []))
 
-        self.assertEquals(len(err_list), 1)
+        self.assertEqual(len(err_list), 1)
         self.assertTrue("'fn-group'" in err_list[0].message)
 
     def test_proposition_3_case_2(self):
@@ -379,7 +379,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         ∃ContractNo<ack> [ ¬Registered(FundingGroup, ContractNo) ] ^
         ∀ContractNo<funding-group> [ Registered(Ack, ContractNo) v Registered(Fn, ContractNo) ]
         """
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <article>
           <front>
             <article-meta>
@@ -408,7 +408,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.funding_group((et, []))
 
-        self.assertEquals(len(err_list), 1)
+        self.assertEqual(len(err_list), 1)
         self.assertTrue("'ack'" in err_list[0].message)
 
     def test_proposition_3_case_3(self):
@@ -417,7 +417,7 @@ class FundingGroupPipeTests(unittest.TestCase):
         ∀ContractNo<ack> [ Registered(FundingGroup, ContractNo) ] ^
         ∃ContractNo<funding-group> [ ¬(Registered(Ack, ContractNo)) ^ ¬(Registered(Fn, ContractNo)) ]
         """
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <article>
           <front>
             <article-meta>
@@ -447,14 +447,14 @@ class FundingGroupPipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.funding_group((et, []))
 
-        self.assertEquals(len(err_list), 1)
+        self.assertEqual(len(err_list), 1)
         self.assertTrue("'funding-group'" in err_list[0].message)
 
 
 class DoctypePipeTests(unittest.TestCase):
 
     def test_missing_doctype(self):
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <article>
           ...
         </article>
@@ -463,11 +463,11 @@ class DoctypePipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.doctype((et, []))
 
-        self.assertEquals(len(err_list), 1)
+        self.assertEqual(len(err_list), 1)
         self.assertTrue("DOCTYPE" in err_list[0].message)
 
     def test_doctype(self):
-        sample = StringIO("""
+        sample = io.BytesIO(b"""
         <!DOCTYPE article PUBLIC "-//NLM//DTD JATS (Z39.96) Journal Publishing DTD v1.0 20120330//EN" "JATS-journalpublishing1.dtd">
         <article>
           ...
@@ -477,5 +477,5 @@ class DoctypePipeTests(unittest.TestCase):
         et = etree.parse(sample)
         _, err_list = checks.doctype((et, []))
 
-        self.assertEquals(len(err_list), 0)
+        self.assertEqual(len(err_list), 0)
 
